import React, { useEffect } from 'react'
import { RouteComponentProps } from 'react-router'

import { Project } from '@agiliza/api/domain/project'
import { PATHS } from '@agiliza/views/Main/DrawerItems'
import {
  Avatar,
  CircularProgress,
  List,
  ListItem,
  ListItemAvatar,
  ListItemText,
  ListSubheader
} from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'
import { Apps as AppsIcon } from '@material-ui/icons'

import { connected, ConnectedProps } from './connect'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles> & ConnectedProps & RouteComponentProps

interface Props extends ExtendedProps {}

const ListProjects = (props: Props) => {
  const { classes, fetching, proposals, history } = props

  useEffect(() => {
    props.getProjects()
  }, [])

  const handleClickListItem = (proposal: Project) => () => {
    props.setProposalId(proposal.id)
    history.push({ pathname: PATHS.proposalData, state: { proposalId: proposal.id } })
  }

  if (fetching) return <CircularProgress />

  return (
    <div className={classes.pageContent}>
      <List
        className={classes.list}
        subheader={
          <ListSubheader component="div" id="nested-list-subheader">
            Projetos
          </ListSubheader>
        }
      >
        {proposals.map((proposal, i) => (
          <ListItem key={i} button onClick={handleClickListItem(proposal)}>
            <ListItemAvatar>
              <Avatar>
                <AppsIcon />
              </Avatar>
            </ListItemAvatar>
            <ListItemText primary="Número da proposta" secondary={proposal.processNumber} />
          </ListItem>
        ))}
      </List>
    </div>
  )
}

export default connected(withStyles(styles)(ListProjects))
