import React, { lazy, Suspense } from 'react'
import { Route, RouteComponentProps, Switch } from 'react-router'

import AuthRoute from '@agiliza/components/atoms/AuthRoute'
import { PATHS } from '@agiliza/views/Main/DrawerItems'
import { CircularProgress } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import styles from './shared-styles'

export const PROJECTS_PATHS = {
  login: PATHS.proposals + '/login',
}

const ListProjects = lazy(() => import('./ListProjects'))
const Login = lazy(() => import('@agiliza/views/Login'))

type ExtendedProps = WithStyles<typeof styles> & RouteComponentProps

interface Props extends ExtendedProps {}

const ProposalDataRouter = (props: Props) => {
  const { classes } = props

  return (
    <div className={classes.pageContent}>
      <Suspense fallback={<CircularProgress className={classes.circularProgress} />}>
        <Switch>
          <Route path={PROJECTS_PATHS.login} render={(renderProps) => <Login {...renderProps} redirectTo={PATHS.proposals} />} />
          <AuthRoute path={PATHS.proposals} redirectTo={PROJECTS_PATHS.login} component={ListProjects} />
        </Switch>
      </Suspense>
    </div>
  )
}

export default withStyles(styles)(ProposalDataRouter)
